.. _showcase:

Community Showcase
==================

.. list-table::
   :widths: 25 50 25
   :header-rows: 1

   * - Title
     - Short Description
     - User
   * - `sktime: a unified python library for time series machine learning <https://towardsdatascience.com/sktime-a-unified-python-library-for-time-series-machine-learning-3c103c139a55>`_
     -  Gives insights on importance of skime over scikit-learn, Proper Data Model for Time Series, and Highlights on unique features of sktime like sktime API, Code Examples of Time Series Models
     - :user:`Alexandra Amidon <lynnssi>`
   * - `Why start using sktime for forecasting? <https://medium.com/@jlenczuk/why-start-using-sktime-for-forecasting-8d6881c0a518>`_
     - Overview of sktime’s features that distinguish it from other forecasting frameworks
     - :user:`Joanna Lenczuk <joanlenczuk>`
   * - `Time Series Analysis with sktime on AWS SageMaker <https://datachef.co/blog/time-series-analysis-sktime-sagemaker/>`_
     - This guide explains the procedure of using sktime as a toolbox for time series analysis on the AWS SageMaker environment.
     - :user:`DataChef.co <DataChefHQ>`
